Here's a sample return when calling `namethis(3)` to help understand what's available under which key.

The important bit is that regardless of the parameter provided, the default resource name set (no index) is always returned.

```json
{
    "aadb2c_directory": "aadb2c-0000-uat",
    "aadb2c_directory1": "aadb2c-0000-uat-01",
    "aadb2c_directory2": "aadb2c-0000-uat-02",
    "aadb2c_directory3": "aadb2c-0000-uat-03",
    "aks_node_pool_linux": "npl0000uat",
    "aks_node_pool_linux1": "npl0000uat01",
    "aks_node_pool_linux2": "npl0000uat02",
    "aks_node_pool_linux3": "npl0000uat03",
    "aks_node_pool_windows": "npw",
    "aks_node_pool_windows1": "npw01",
    "aks_node_pool_windows2": "npw02",
    "aks_node_pool_windows3": "npw03",
    "analysis_services_server": "as0000uataue",
    "analysis_services_server1": "as0000uat01",
    "analysis_services_server2": "as0000uat02",
    "analysis_services_server3": "as0000uat03",
    "api_management": "apim-0000-uat",
    "api_management1": "apim-0000-uat-01",
    "api_management2": "apim-0000-uat-02",
    "api_management3": "apim-0000-uat-03",
    "api_management_api": "apimapi-0000-uat",
    "api_management_api1": "apimapi-0000-uat-01",
    "api_management_api2": "apimapi-0000-uat-02",
    "api_management_api3": "apimapi-0000-uat-03",
    "api_management_api_operation_tag": "apimapiopt-0000-uat",
    "api_management_api_operation_tag1": "apimapiopt-0000-uat-01",
    "api_management_api_operation_tag2": "apimapiopt-0000-uat-02",
    "api_management_api_operation_tag3": "apimapiopt-0000-uat-03",
    "api_management_backend": "apimbe-0000-uat",
    "api_management_backend1": "apimbe-0000-uat-01",
    "api_management_backend2": "apimbe-0000-uat-02",
    "api_management_backend3": "apimbe-0000-uat-03",
    "api_management_certificate": "apimcer-0000-uat",
    "api_management_certificate1": "apimcer-0000-uat-01",
    "api_management_certificate2": "apimcer-0000-uat-02",
    "api_management_certificate3": "apimcer-0000-uat-03",
    "api_management_gateway": "apimgw-0000-uat",
    "api_management_gateway1": "apimgw-0000-uat-01",
    "api_management_gateway2": "apimgw-0000-uat-02",
    "api_management_gateway3": "apimgw-0000-uat-03",
    "api_management_group": "apimgr-0000-uat",
    "api_management_group1": "apimgr-0000-uat-01",
    "api_management_group2": "apimgr-0000-uat-02",
    "api_management_group3": "apimgr-0000-uat-03",
    "api_management_logger": "apimlg-0000-uat",
    "api_management_logger1": "apimlg-0000-uat-01",
    "api_management_logger2": "apimlg-0000-uat-02",
    "api_management_logger3": "apimlg-0000-uat-03",
    "api_management_service": "apim-0000-uat",
    "api_management_service1": "apim-0000-uat-01",
    "api_management_service2": "apim-0000-uat-02",
    "api_management_service3": "apim-0000-uat-03",
    "app_configuration": "appcg-0000-uat-aue",
    "app_configuration1": "appcg-0000-uat-01",
    "app_configuration2": "appcg-0000-uat-02",
    "app_configuration3": "appcg-0000-uat-03",
    "app_service": "app-0000-uat",
    "app_service1": "app-0000-uat-01",
    "app_service2": "app-0000-uat-02",
    "app_service3": "app-0000-uat-03",
    "app_service_environment": "ase-0000-uat-aue",
    "app_service_environment1": "ase-0000-uat-01",
    "app_service_environment2": "ase-0000-uat-02",
    "app_service_environment3": "ase-0000-uat-03",
    "app_service_plan": "plan-0000-uat-aue",
    "app_service_plan1": "plan-0000-uat-01",
    "app_service_plan2": "plan-0000-uat-02",
    "app_service_plan3": "plan-0000-uat-03",
    "application_gateway": "agw-0000-uat-aue",
    "application_gateway1": "agw-0000-uat-01",
    "application_gateway2": "agw-0000-uat-02",
    "application_gateway3": "agw-0000-uat-03",
    "application_insights": "appi-0000-uat-aue",
    "application_insights1": "appi-0000-uat-01",
    "application_insights2": "appi-0000-uat-02",
    "application_insights3": "appi-0000-uat-03",
    "application_insights_web_test": "appiwt-0000-uat-aue",
    "application_insights_web_test1": "appiwt-0000-uat-01",
    "application_insights_web_test2": "appiwt-0000-uat-02",
    "application_insights_web_test3": "appiwt-0000-uat-03",
    "application_security_group": "asg-0000-uat-aue",
    "application_security_group1": "asg-0000-uat-01",
    "application_security_group2": "asg-0000-uat-02",
    "application_security_group3": "asg-0000-uat-03",
    "automation_account": "aa-0000-uat-aue",
    "automation_account1": "aa-0000-uat-01",
    "automation_account2": "aa-0000-uat-02",
    "automation_account3": "aa-0000-uat-03",
    "automation_certificate": "aacert-0000-uat-aue",
    "automation_certificate1": "aacert-0000-uat-01",
    "automation_certificate2": "aacert-0000-uat-02",
    "automation_certificate3": "aacert-0000-uat-03",
    "automation_credential": "aacred-0000-uat-aue",
    "automation_credential1": "aacred-0000-uat-01",
    "automation_credential2": "aacred-0000-uat-02",
    "automation_credential3": "aacred-0000-uat-03",
    "automation_hybrid_runbook_worker_group": "aahwg-0000-uat-aue",
    "automation_hybrid_runbook_worker_group1": "aahwg-0000-uat-01",
    "automation_hybrid_runbook_worker_group2": "aahwg-0000-uat-02",
    "automation_hybrid_runbook_worker_group3": "aahwg-0000-uat-03",
    "automation_job_schedule": "aajs-0000-uat-aue",
    "automation_job_schedule1": "aajs-0000-uat-01",
    "automation_job_schedule2": "aajs-0000-uat-02",
    "automation_job_schedule3": "aajs-0000-uat-03",
    "automation_runbook": "aarun-0000-uat-aue",
    "automation_runbook1": "aarun-0000-uat-01",
    "automation_runbook2": "aarun-0000-uat-02",
    "automation_runbook3": "aarun-0000-uat-03",
    "automation_schedule": "aasched-0000-uat-aue",
    "automation_schedule1": "aasched-0000-uat-01",
    "automation_schedule2": "aasched-0000-uat-02",
    "automation_schedule3": "aasched-0000-uat-03",
    "automation_variable": "aavar-0000-uat-aue",
    "automation_variable1": "aavar-0000-uat-01",
    "automation_variable2": "aavar-0000-uat-02",
    "automation_variable3": "aavar-0000-uat-03",
    "availability_set": "avail-0000-uat-aue",
    "availability_set1": "avail-0000-uat-01",
    "availability_set2": "avail-0000-uat-02",
    "availability_set3": "avail-0000-uat-03",
    "bastion_host": "bast-0000-uat-aue",
    "bastion_host1": "bast-0000-uat-01",
    "bastion_host2": "bast-0000-uat-02",
    "bastion_host3": "bast-0000-uat-03",
    "batch_account": "ba0000uataue",
    "batch_account1": "ba0000uat01",
    "batch_account2": "ba0000uat02",
    "batch_account3": "ba0000uat03",
    "batch_application": "baapp-0000-uat-aue",
    "batch_application1": "baapp-0000-uat-01",
    "batch_application2": "baapp-0000-uat-02",
    "batch_application3": "baapp-0000-uat-03",
    "batch_certificate": "bacert-0000-uat-aue",
    "batch_certificate1": "bacert-0000-uat-01",
    "batch_certificate2": "bacert-0000-uat-02",
    "batch_certificate3": "bacert-0000-uat-03",
    "batch_pool": "bapool-0000-uat-aue",
    "batch_pool1": "bapool-0000-uat-01",
    "batch_pool2": "bapool-0000-uat-02",
    "batch_pool3": "bapool-0000-uat-03",
    "bot_channel_directline": "botline-0000-uat-aue",
    "bot_channel_directline1": "botline-0000-uat-01",
    "bot_channel_directline2": "botline-0000-uat-02",
    "bot_channel_directline3": "botline-0000-uat-03",
    "bot_channel_email": "botmail-0000-uat-aue",
    "bot_channel_email1": "botmail-0000-uat-01",
    "bot_channel_email2": "botmail-0000-uat-02",
    "bot_channel_email3": "botmail-0000-uat-03",
    "bot_channel_ms_teams": "botteams-0000-uat-aue",
    "bot_channel_ms_teams1": "botteams-0000-uat-01",
    "bot_channel_ms_teams2": "botteams-0000-uat-02",
    "bot_channel_ms_teams3": "botteams-0000-uat-03",
    "bot_channel_slack": "botslack-0000-uat-aue",
    "bot_channel_slack1": "botslack-0000-uat-01",
    "bot_channel_slack2": "botslack-0000-uat-02",
    "bot_channel_slack3": "botslack-0000-uat-03",
    "bot_channels_registration": "botchan-0000-uat-aue",
    "bot_channels_registration1": "botchan-0000-uat-01",
    "bot_channels_registration2": "botchan-0000-uat-02",
    "bot_channels_registration3": "botchan-0000-uat-03",
    "bot_connection": "botcon-0000-uat-aue",
    "bot_connection1": "botcon-0000-uat-01",
    "bot_connection2": "botcon-0000-uat-02",
    "bot_connection3": "botcon-0000-uat-03",
    "bot_web_app": "bot-0000-uat",
    "bot_web_app1": "bot-0000-uat-01",
    "bot_web_app2": "bot-0000-uat-02",
    "bot_web_app3": "bot-0000-uat-03",
    "cdn_endpoint": "cdn-0000-uat",
    "cdn_endpoint1": "cdn-0000-uat-01",
    "cdn_endpoint2": "cdn-0000-uat-02",
    "cdn_endpoint3": "cdn-0000-uat-03",
    "cdn_frontdoor_custom_domain": "cfdcd-0000-uat-aue",
    "cdn_frontdoor_custom_domain1": "cfdcd-0000-uat-01",
    "cdn_frontdoor_custom_domain2": "cfdcd-0000-uat-02",
    "cdn_frontdoor_custom_domain3": "cfdcd-0000-uat-03",
    "cdn_frontdoor_endpoint": "cfde-0000-uat",
    "cdn_frontdoor_endpoint1": "cfde-0000-uat-01",
    "cdn_frontdoor_endpoint2": "cfde-0000-uat-02",
    "cdn_frontdoor_endpoint3": "cfde-0000-uat-03",
    "cdn_frontdoor_firewall_policy": "cfdfp0000uataue",
    "cdn_frontdoor_firewall_policy1": "cfdfp0000uat01",
    "cdn_frontdoor_firewall_policy2": "cfdfp0000uat02",
    "cdn_frontdoor_firewall_policy3": "cfdfp0000uat03",
    "cdn_frontdoor_origin": "cfdo-0000-uat-aue",
    "cdn_frontdoor_origin1": "cfdo-0000-uat-01",
    "cdn_frontdoor_origin2": "cfdo-0000-uat-02",
    "cdn_frontdoor_origin3": "cfdo-0000-uat-03",
    "cdn_frontdoor_origin_group": "cfdog-0000-uat-aue",
    "cdn_frontdoor_origin_group1": "cfdog-0000-uat-01",
    "cdn_frontdoor_origin_group2": "cfdog-0000-uat-02",
    "cdn_frontdoor_origin_group3": "cfdog-0000-uat-03",
    "cdn_frontdoor_profile": "cfdp-0000-uat-aue",
    "cdn_frontdoor_profile1": "cfdp-0000-uat-01",
    "cdn_frontdoor_profile2": "cfdp-0000-uat-02",
    "cdn_frontdoor_profile3": "cfdp-0000-uat-03",
    "cdn_frontdoor_route": "cfdroute-0000-uat-aue",
    "cdn_frontdoor_route1": "cfdroute-0000-uat-01",
    "cdn_frontdoor_route2": "cfdroute-0000-uat-02",
    "cdn_frontdoor_route3": "cfdroute-0000-uat-03",
    "cdn_frontdoor_rule": "cfdr0000uataue",
    "cdn_frontdoor_rule1": "cfdr0000uat01",
    "cdn_frontdoor_rule2": "cfdr0000uat02",
    "cdn_frontdoor_rule3": "cfdr0000uat03",
    "cdn_frontdoor_rule_set": "cfdrs0000uataue",
    "cdn_frontdoor_rule_set1": "cfdrs0000uat01",
    "cdn_frontdoor_rule_set2": "cfdrs0000uat02",
    "cdn_frontdoor_rule_set3": "cfdrs0000uat03",
    "cdn_frontdoor_secret": "cfds-0000-uat-aue",
    "cdn_frontdoor_secret1": "cfds-0000-uat-01",
    "cdn_frontdoor_secret2": "cfds-0000-uat-02",
    "cdn_frontdoor_secret3": "cfds-0000-uat-03",
    "cdn_frontdoor_security_policy": "cfdsp-0000-uat-aue",
    "cdn_frontdoor_security_policy1": "cfdsp-0000-uat-01",
    "cdn_frontdoor_security_policy2": "cfdsp-0000-uat-02",
    "cdn_frontdoor_security_policy3": "cfdsp-0000-uat-03",
    "cdn_profile": "cdnprof-0000-uat-aue",
    "cdn_profile1": "cdnprof-0000-uat-01",
    "cdn_profile2": "cdnprof-0000-uat-02",
    "cdn_profile3": "cdnprof-0000-uat-03",
    "cognitive_account": "cog-0000-uat-aue",
    "cognitive_account1": "cog-0000-uat-01",
    "cognitive_account2": "cog-0000-uat-02",
    "cognitive_account3": "cog-0000-uat-03",
    "communication_service": "acs-0000-uat-aue",
    "communication_service1": "acs-0000-uat-01",
    "communication_service2": "acs-0000-uat-02",
    "communication_service3": "acs-0000-uat-03",
    "consumption_budget_resource_group": "acbrg-0000-uat-aue",
    "consumption_budget_resource_group1": "acbrg-0000-uat-01",
    "consumption_budget_resource_group2": "acbrg-0000-uat-02",
    "consumption_budget_resource_group3": "acbrg-0000-uat-03",
    "consumption_budget_subscription": "acbs-0000-uat-aue",
    "consumption_budget_subscription1": "acbs-0000-uat-01",
    "consumption_budget_subscription2": "acbs-0000-uat-02",
    "consumption_budget_subscription3": "acbs-0000-uat-03",
    "container_app": "ca-0000-uat-aue",
    "container_app1": "ca-0000-uat-01",
    "container_app2": "ca-0000-uat-02",
    "container_app3": "ca-0000-uat-03",
    "container_app_environment": "cae-0000-uat-aue",
    "container_app_environment1": "cae-0000-uat-01",
    "container_app_environment2": "cae-0000-uat-02",
    "container_app_environment3": "cae-0000-uat-03",
    "container_registry": "cr0000uataue",
    "container_registry1": "cr0000uat01",
    "container_registry2": "cr0000uat02",
    "container_registry3": "cr0000uat03",
    "container_registry_webhook": "crwh0000uataue",
    "container_registry_webhook1": "crwh0000uat01",
    "container_registry_webhook2": "crwh0000uat02",
    "container_registry_webhook3": "crwh0000uat03",
    "containergroups": "cg-0000-uat-aue",
    "containergroups1": "cg-0000-uat-01",
    "containergroups2": "cg-0000-uat-02",
    "containergroups3": "cg-0000-uat-03",
    "cosmosdb_account": "cosmos-0000-uat-aue",
    "cosmosdb_account1": "cosmos-0000-uat-01",
    "cosmosdb_account2": "cosmos-0000-uat-02",
    "cosmosdb_account3": "cosmos-0000-uat-03",
    "custom_provider": "prov-0000-uat-aue",
    "custom_provider1": "prov-0000-uat-01",
    "custom_provider2": "prov-0000-uat-02",
    "custom_provider3": "prov-0000-uat-03",
    "dashboard": "dsb-0000-uat-aue",
    "dashboard1": "dsb-0000-uat-01",
    "dashboard2": "dsb-0000-uat-02",
    "dashboard3": "dsb-0000-uat-03",
    "data_factory": "adf-0000-uat",
    "data_factory1": "adf-0000-uat-01",
    "data_factory2": "adf-0000-uat-02",
    "data_factory3": "adf-0000-uat-03",
    "data_factory_dataset_azure_blob": "adfblob-0000-uat-aue",
    "data_factory_dataset_azure_blob1": "adfblob-0000-uat-01",
    "data_factory_dataset_azure_blob2": "adfblob-0000-uat-02",
    "data_factory_dataset_azure_blob3": "adfblob-0000-uat-03",
    "data_factory_dataset_cosmosdb_sqlapi": "adfsqlapi-0000-uat-aue",
    "data_factory_dataset_cosmosdb_sqlapi1": "adfsqlapi-0000-uat-01",
    "data_factory_dataset_cosmosdb_sqlapi2": "adfsqlapi-0000-uat-02",
    "data_factory_dataset_cosmosdb_sqlapi3": "adfsqlapi-0000-uat-03",
    "data_factory_dataset_delimited_text": "adfdtext-0000-uat-aue",
    "data_factory_dataset_delimited_text1": "adfdtext-0000-uat-01",
    "data_factory_dataset_delimited_text2": "adfdtext-0000-uat-02",
    "data_factory_dataset_delimited_text3": "adfdtext-0000-uat-03",
    "data_factory_dataset_http": "adfhttp-0000-uat-aue",
    "data_factory_dataset_http1": "adfhttp-0000-uat-01",
    "data_factory_dataset_http2": "adfhttp-0000-uat-02",
    "data_factory_dataset_http3": "adfhttp-0000-uat-03",
    "data_factory_dataset_json": "adfjson-0000-uat-aue",
    "data_factory_dataset_json1": "adfjson-0000-uat-01",
    "data_factory_dataset_json2": "adfjson-0000-uat-02",
    "data_factory_dataset_json3": "adfjson-0000-uat-03",
    "data_factory_dataset_mysql": "adfmysql-0000-uat-aue",
    "data_factory_dataset_mysql1": "adfmysql-0000-uat-01",
    "data_factory_dataset_mysql2": "adfmysql-0000-uat-02",
    "data_factory_dataset_mysql3": "adfmysql-0000-uat-03",
    "data_factory_dataset_postgresql": "adfpsql-0000-uat-aue",
    "data_factory_dataset_postgresql1": "adfpsql-0000-uat-01",
    "data_factory_dataset_postgresql2": "adfpsql-0000-uat-02",
    "data_factory_dataset_postgresql3": "adfpsql-0000-uat-03",
    "data_factory_dataset_sql_server_table": "adfmssql-0000-uat-aue",
    "data_factory_dataset_sql_server_table1": "adfmssql-0000-uat-01",
    "data_factory_dataset_sql_server_table2": "adfmssql-0000-uat-02",
    "data_factory_dataset_sql_server_table3": "adfmssql-0000-uat-03",
    "data_factory_integration_runtime_managed": "adfir-0000-uat-aue",
    "data_factory_integration_runtime_managed1": "adfir-0000-uat-01",
    "data_factory_integration_runtime_managed2": "adfir-0000-uat-02",
    "data_factory_integration_runtime_managed3": "adfir-0000-uat-03",
    "data_factory_linked_service_azure_blob_storage": "adflsabs-0000-uat-aue",
    "data_factory_linked_service_azure_blob_storage1": "adflsabs-0000-uat-01",
    "data_factory_linked_service_azure_blob_storage2": "adflsabs-0000-uat-02",
    "data_factory_linked_service_azure_blob_storage3": "adflsabs-0000-uat-03",
    "data_factory_linked_service_azure_databricks": "adflsadb-0000-uat-aue",
    "data_factory_linked_service_azure_databricks1": "adflsadb-0000-uat-01",
    "data_factory_linked_service_azure_databricks2": "adflsadb-0000-uat-02",
    "data_factory_linked_service_azure_databricks3": "adflsadb-0000-uat-03",
    "data_factory_linked_service_azure_function": "adflsaf-0000-uat-aue",
    "data_factory_linked_service_azure_function1": "adflsaf-0000-uat-01",
    "data_factory_linked_service_azure_function2": "adflsaf-0000-uat-02",
    "data_factory_linked_service_azure_function3": "adflsaf-0000-uat-03",
    "data_factory_linked_service_azure_sql_database": "adflsasdb-0000-uat-aue",
    "data_factory_linked_service_azure_sql_database1": "adflsasdb-0000-uat-01",
    "data_factory_linked_service_azure_sql_database2": "adflsasdb-0000-uat-02",
    "data_factory_linked_service_azure_sql_database3": "adflsasdb-0000-uat-03",
    "data_factory_linked_service_cosmosdb": "adflsacdb-0000-uat-aue",
    "data_factory_linked_service_cosmosdb1": "adflsacdb-0000-uat-01",
    "data_factory_linked_service_cosmosdb2": "adflsacdb-0000-uat-02",
    "data_factory_linked_service_cosmosdb3": "adflsacdb-0000-uat-03",
    "data_factory_linked_service_data_lake_storage_gen2": "adfsvst-0000-uat-aue",
    "data_factory_linked_service_data_lake_storage_gen21": "adfsvst-0000-uat-01",
    "data_factory_linked_service_data_lake_storage_gen22": "adfsvst-0000-uat-02",
    "data_factory_linked_service_data_lake_storage_gen23": "adfsvst-0000-uat-03",
    "data_factory_linked_service_key_vault": "adfsvkv-0000-uat-aue",
    "data_factory_linked_service_key_vault1": "adfsvkv-0000-uat-01",
    "data_factory_linked_service_key_vault2": "adfsvkv-0000-uat-02",
    "data_factory_linked_service_key_vault3": "adfsvkv-0000-uat-03",
    "data_factory_linked_service_mysql": "adfsvmysql-0000-uat-aue",
    "data_factory_linked_service_mysql1": "adfsvmysql-0000-uat-01",
    "data_factory_linked_service_mysql2": "adfsvmysql-0000-uat-02",
    "data_factory_linked_service_mysql3": "adfsvmysql-0000-uat-03",
    "data_factory_linked_service_postgresql": "adfsvpsql-0000-uat-aue",
    "data_factory_linked_service_postgresql1": "adfsvpsql-0000-uat-01",
    "data_factory_linked_service_postgresql2": "adfsvpsql-0000-uat-02",
    "data_factory_linked_service_postgresql3": "adfsvpsql-0000-uat-03",
    "data_factory_linked_service_sftp": "adflsaftp-0000-uat-aue",
    "data_factory_linked_service_sftp1": "adflsaftp-0000-uat-01",
    "data_factory_linked_service_sftp2": "adflsaftp-0000-uat-02",
    "data_factory_linked_service_sftp3": "adflsaftp-0000-uat-03",
    "data_factory_linked_service_sql_server": "adfsvmssql-0000-uat-aue",
    "data_factory_linked_service_sql_server1": "adfsvmssql-0000-uat-01",
    "data_factory_linked_service_sql_server2": "adfsvmssql-0000-uat-02",
    "data_factory_linked_service_sql_server3": "adfsvmssql-0000-uat-03",
    "data_factory_linked_service_web": "adfsvweb-0000-uat-aue",
    "data_factory_linked_service_web1": "adfsvweb-0000-uat-01",
    "data_factory_linked_service_web2": "adfsvweb-0000-uat-02",
    "data_factory_linked_service_web3": "adfsvweb-0000-uat-03",
    "data_factory_pipeline": "adfpl-0000-uat-aue",
    "data_factory_pipeline1": "adfpl-0000-uat-01",
    "data_factory_pipeline2": "adfpl-0000-uat-02",
    "data_factory_pipeline3": "adfpl-0000-uat-03",
    "data_factory_trigger_schedule": "adftg-0000-uat-aue",
    "data_factory_trigger_schedule1": "adftg-0000-uat-01",
    "data_factory_trigger_schedule2": "adftg-0000-uat-02",
    "data_factory_trigger_schedule3": "adftg-0000-uat-03",
    "data_lake_analytics_account": "dla0000uat",
    "data_lake_analytics_account1": "dla0000uat01",
    "data_lake_analytics_account2": "dla0000uat02",
    "data_lake_analytics_account3": "dla0000uat03",
    "data_lake_analytics_firewall_rule": "dlfw-0000-uat-aue",
    "data_lake_analytics_firewall_rule1": "dlfw-0000-uat-01",
    "data_lake_analytics_firewall_rule2": "dlfw-0000-uat-02",
    "data_lake_analytics_firewall_rule3": "dlfw-0000-uat-03",
    "data_lake_store": "dls0000uataue",
    "data_lake_store1": "dls0000uat01",
    "data_lake_store2": "dls0000uat02",
    "data_lake_store3": "dls0000uat03",
    "data_lake_store_firewall_rule": "dlsfw-0000-uat-aue",
    "data_lake_store_firewall_rule1": "dlsfw-0000-uat-01",
    "data_lake_store_firewall_rule2": "dlsfw-0000-uat-02",
    "data_lake_store_firewall_rule3": "dlsfw-0000-uat-03",
    "data_protection_backup_policy_blob_storage": "dpbpb-0000-uat-aue",
    "data_protection_backup_policy_blob_storage1": "dpbpb-0000-uat-01",
    "data_protection_backup_policy_blob_storage2": "dpbpb-0000-uat-02",
    "data_protection_backup_policy_blob_storage3": "dpbpb-0000-uat-03",
    "data_protection_backup_policy_disk": "dpbpd-0000-uat-aue",
    "data_protection_backup_policy_disk1": "dpbpd-0000-uat-01",
    "data_protection_backup_policy_disk2": "dpbpd-0000-uat-02",
    "data_protection_backup_policy_disk3": "dpbpd-0000-uat-03",
    "data_protection_backup_policy_postgresql": "dpbpp-0000-uat-aue",
    "data_protection_backup_policy_postgresql1": "dpbpp-0000-uat-01",
    "data_protection_backup_policy_postgresql2": "dpbpp-0000-uat-02",
    "data_protection_backup_policy_postgresql3": "dpbpp-0000-uat-03",
    "data_protection_backup_vault": "dpbv-0000-uat-aue",
    "data_protection_backup_vault1": "dpbv-0000-uat-01",
    "data_protection_backup_vault2": "dpbv-0000-uat-02",
    "data_protection_backup_vault3": "dpbv-0000-uat-03",
    "database_migration_project": "migr-0000-uat-aue",
    "database_migration_project1": "migr-0000-uat-01",
    "database_migration_project2": "migr-0000-uat-02",
    "database_migration_project3": "migr-0000-uat-03",
    "database_migration_service": "dms-0000-uat-aue",
    "database_migration_service1": "dms-0000-uat-01",
    "database_migration_service2": "dms-0000-uat-02",
    "database_migration_service3": "dms-0000-uat-03",
    "databricks_workspace": "dbw-0000-uat-aue",
    "databricks_workspace1": "dbw-0000-uat-01",
    "databricks_workspace2": "dbw-0000-uat-02",
    "databricks_workspace3": "dbw-0000-uat-03",
    "dedicated_host": "dh-0000-uat-aue",
    "dedicated_host1": "dh-0000-uat-01",
    "dedicated_host2": "dh-0000-uat-02",
    "dedicated_host3": "dh-0000-uat-03",
    "dedicated_host_group": "dhg-0000-uat-aue",
    "dedicated_host_group1": "dhg-0000-uat-01",
    "dedicated_host_group2": "dhg-0000-uat-02",
    "dedicated_host_group3": "dhg-0000-uat-03",
    "dev_test_lab": "lab-0000-uat-aue",
    "dev_test_lab1": "lab-0000-uat-01",
    "dev_test_lab2": "lab-0000-uat-02",
    "dev_test_lab3": "lab-0000-uat-03",
    "dev_test_linux_virtual_machine": "labvm-0000-uat-aue",
    "dev_test_linux_virtual_machine1": "labvm-0000-uat-01",
    "dev_test_linux_virtual_machine2": "labvm-0000-uat-02",
    "dev_test_linux_virtual_machine3": "labvm-0000-uat-03",
    "dev_test_windows_virtual_machine": "labvm0000uataue",
    "dev_test_windows_virtual_machine1": "labvm0000uat01",
    "dev_test_windows_virtual_machine2": "labvm0000uat02",
    "dev_test_windows_virtual_machine3": "labvm0000uat03",
    "digital_twins_endpoint_eventgrid": "adteg-0000-uat-aue",
    "digital_twins_endpoint_eventgrid1": "adteg-0000-uat-01",
    "digital_twins_endpoint_eventgrid2": "adteg-0000-uat-02",
    "digital_twins_endpoint_eventgrid3": "adteg-0000-uat-03",
    "digital_twins_endpoint_eventhub": "adteh-0000-uat-aue",
    "digital_twins_endpoint_eventhub1": "adteh-0000-uat-01",
    "digital_twins_endpoint_eventhub2": "adteh-0000-uat-02",
    "digital_twins_endpoint_eventhub3": "adteh-0000-uat-03",
    "digital_twins_endpoint_servicebus": "adtsb-0000-uat-aue",
    "digital_twins_endpoint_servicebus1": "adtsb-0000-uat-01",
    "digital_twins_endpoint_servicebus2": "adtsb-0000-uat-02",
    "digital_twins_endpoint_servicebus3": "adtsb-0000-uat-03",
    "digital_twins_instance": "adt-0000-uat-aue",
    "digital_twins_instance1": "adt-0000-uat-01",
    "digital_twins_instance2": "adt-0000-uat-02",
    "digital_twins_instance3": "adt-0000-uat-03",
    "disk_encryption_set": "des-0000-uat-aue",
    "disk_encryption_set1": "des-0000-uat-01",
    "disk_encryption_set2": "des-0000-uat-02",
    "disk_encryption_set3": "des-0000-uat-03",
    "dns_zone": "dns-0000-uat-aue",
    "dns_zone1": "dns-0000-uat-01",
    "dns_zone2": "dns-0000-uat-02",
    "dns_zone3": "dns-0000-uat-03",
    "eventgrid_domain": "egd-0000-uat-aue",
    "eventgrid_domain1": "egd-0000-uat-01",
    "eventgrid_domain2": "egd-0000-uat-02",
    "eventgrid_domain3": "egd-0000-uat-03",
    "eventgrid_domain_topic": "egdt-0000-uat-aue",
    "eventgrid_domain_topic1": "egdt-0000-uat-01",
    "eventgrid_domain_topic2": "egdt-0000-uat-02",
    "eventgrid_domain_topic3": "egdt-0000-uat-03",
    "eventgrid_event_subscription": "egs-0000-uat-aue",
    "eventgrid_event_subscription1": "egs-0000-uat-01",
    "eventgrid_event_subscription2": "egs-0000-uat-02",
    "eventgrid_event_subscription3": "egs-0000-uat-03",
    "eventgrid_topic": "egt-0000-uat-aue",
    "eventgrid_topic1": "egt-0000-uat-01",
    "eventgrid_topic2": "egt-0000-uat-02",
    "eventgrid_topic3": "egt-0000-uat-03",
    "eventhub": "evh-0000-uat-aue",
    "eventhub1": "evh-0000-uat-01",
    "eventhub2": "evh-0000-uat-02",
    "eventhub3": "evh-0000-uat-03",
    "eventhub_authorization_rule": "ehar-0000-uat-aue",
    "eventhub_authorization_rule1": "ehar-0000-uat-01",
    "eventhub_authorization_rule2": "ehar-0000-uat-02",
    "eventhub_authorization_rule3": "ehar-0000-uat-03",
    "eventhub_consumer_group": "ehcg-0000-uat-aue",
    "eventhub_consumer_group1": "ehcg-0000-uat-01",
    "eventhub_consumer_group2": "ehcg-0000-uat-02",
    "eventhub_consumer_group3": "ehcg-0000-uat-03",
    "eventhub_namespace": "ehn-0000-uat",
    "eventhub_namespace1": "ehn-0000-uat-01",
    "eventhub_namespace2": "ehn-0000-uat-02",
    "eventhub_namespace3": "ehn-0000-uat-03",
    "eventhub_namespace_authorization_rule": "ehnar-0000-uat-aue",
    "eventhub_namespace_authorization_rule1": "ehnar-0000-uat-01",
    "eventhub_namespace_authorization_rule2": "ehnar-0000-uat-02",
    "eventhub_namespace_authorization_rule3": "ehnar-0000-uat-03",
    "eventhub_namespace_disaster_recovery_config": "ehdr-0000-uat-aue",
    "eventhub_namespace_disaster_recovery_config1": "ehdr-0000-uat-01",
    "eventhub_namespace_disaster_recovery_config2": "ehdr-0000-uat-02",
    "eventhub_namespace_disaster_recovery_config3": "ehdr-0000-uat-03",
    "express_route_circuit": "erc-0000-uat-aue",
    "express_route_circuit1": "erc-0000-uat-01",
    "express_route_circuit2": "erc-0000-uat-02",
    "express_route_circuit3": "erc-0000-uat-03",
    "express_route_gateway": "ergw-0000-uat-aue",
    "express_route_gateway1": "ergw-0000-uat-01",
    "express_route_gateway2": "ergw-0000-uat-02",
    "express_route_gateway3": "ergw-0000-uat-03",
    "federated_identity_credential": "fedcred-0000-uat-aue",
    "federated_identity_credential1": "fedcred-0000-uat-01",
    "federated_identity_credential2": "fedcred-0000-uat-02",
    "federated_identity_credential3": "fedcred-0000-uat-03",
    "firewall": "fw-0000-uat-aue",
    "firewall1": "fw-0000-uat-01",
    "firewall2": "fw-0000-uat-02",
    "firewall3": "fw-0000-uat-03",
    "firewall_policy": "afwp-0000-uat-aue",
    "firewall_policy1": "afwp-0000-uat-01",
    "firewall_policy2": "afwp-0000-uat-02",
    "firewall_policy3": "afwp-0000-uat-03",
    "frontdoor": "fd-0000-uat",
    "frontdoor1": "fd-0000-uat-01",
    "frontdoor2": "fd-0000-uat-02",
    "frontdoor3": "fd-0000-uat-03",
    "frontdoor_firewall_policy": "fdfw0000uat",
    "frontdoor_firewall_policy1": "fdfw0000uat01",
    "frontdoor_firewall_policy2": "fdfw0000uat02",
    "frontdoor_firewall_policy3": "fdfw0000uat03",
    "function_app": "fa-0000-uat",
    "function_app1": "fa-0000-uat-01",
    "function_app2": "fa-0000-uat-02",
    "function_app3": "fa-0000-uat-03",
    "function_app_slot": "fas-0000-uat",
    "function_app_slot1": "fas-0000-uat-01",
    "function_app_slot2": "fas-0000-uat-02",
    "function_app_slot3": "fas-0000-uat-03",
    "hdinsight_hadoop_cluster": "hadoop-0000-uat",
    "hdinsight_hadoop_cluster1": "hadoop-0000-uat-01",
    "hdinsight_hadoop_cluster2": "hadoop-0000-uat-02",
    "hdinsight_hadoop_cluster3": "hadoop-0000-uat-03",
    "hdinsight_hbase_cluster": "hbase-0000-uat",
    "hdinsight_hbase_cluster1": "hbase-0000-uat-01",
    "hdinsight_hbase_cluster2": "hbase-0000-uat-02",
    "hdinsight_hbase_cluster3": "hbase-0000-uat-03",
    "hdinsight_interactive_query_cluster": "iqr-0000-uat",
    "hdinsight_interactive_query_cluster1": "iqr-0000-uat-01",
    "hdinsight_interactive_query_cluster2": "iqr-0000-uat-02",
    "hdinsight_interactive_query_cluster3": "iqr-0000-uat-03",
    "hdinsight_kafka_cluster": "kafka-0000-uat",
    "hdinsight_kafka_cluster1": "kafka-0000-uat-01",
    "hdinsight_kafka_cluster2": "kafka-0000-uat-02",
    "hdinsight_kafka_cluster3": "kafka-0000-uat-03",
    "hdinsight_ml_services_cluster": "mls-0000-uat",
    "hdinsight_ml_services_cluster1": "mls-0000-uat-01",
    "hdinsight_ml_services_cluster2": "mls-0000-uat-02",
    "hdinsight_ml_services_cluster3": "mls-0000-uat-03",
    "hdinsight_rserver_cluster": "rser-0000-uat",
    "hdinsight_rserver_cluster1": "rser-0000-uat-01",
    "hdinsight_rserver_cluster2": "rser-0000-uat-02",
    "hdinsight_rserver_cluster3": "rser-0000-uat-03",
    "hdinsight_spark_cluster": "spark-0000-uat",
    "hdinsight_spark_cluster1": "spark-0000-uat-01",
    "hdinsight_spark_cluster2": "spark-0000-uat-02",
    "hdinsight_spark_cluster3": "spark-0000-uat-03",
    "hdinsight_storm_cluster": "storm-0000-uat",
    "hdinsight_storm_cluster1": "storm-0000-uat-01",
    "hdinsight_storm_cluster2": "storm-0000-uat-02",
    "hdinsight_storm_cluster3": "storm-0000-uat-03",
    "healthcare_dicom_service": "dicom-0000-uat-aue",
    "healthcare_dicom_service1": "dicom-0000-uat-01",
    "healthcare_dicom_service2": "dicom-0000-uat-02",
    "healthcare_dicom_service3": "dicom-0000-uat-03",
    "healthcare_fhir_service": "fhir-0000-uat-aue",
    "healthcare_fhir_service1": "fhir-0000-uat-01",
    "healthcare_fhir_service2": "fhir-0000-uat-02",
    "healthcare_fhir_service3": "fhir-0000-uat-03",
    "healthcare_medtech_service": "medtech-0000-uat-aue",
    "healthcare_medtech_service1": "medtech-0000-uat-01",
    "healthcare_medtech_service2": "medtech-0000-uat-02",
    "healthcare_medtech_service3": "medtech-0000-uat-03",
    "healthcare_service": "hcasvc-0000-uat",
    "healthcare_service1": "hcasvc-0000-uat-01",
    "healthcare_service2": "hcasvc-0000-uat-02",
    "healthcare_service3": "hcasvc-0000-uat-03",
    "healthcare_workspace": "hcw0000uat",
    "healthcare_workspace1": "hcw0000uat01",
    "healthcare_workspace2": "hcw0000uat02",
    "healthcare_workspace3": "hcw0000uat03",
    "image": "img-0000-uat-aue",
    "image1": "img-0000-uat-01",
    "image2": "img-0000-uat-02",
    "image3": "img-0000-uat-03",
    "integration_service_environment": "lappise-0000-uat-aue",
    "integration_service_environment1": "lappise-0000-uat-01",
    "integration_service_environment2": "lappise-0000-uat-02",
    "integration_service_environment3": "lappise-0000-uat-03",
    "iot_security_device_group": "iotdg-0000-uat-aue",
    "iot_security_device_group1": "iotdg-0000-uat-01",
    "iot_security_device_group2": "iotdg-0000-uat-02",
    "iot_security_device_group3": "iotdg-0000-uat-03",
    "iot_security_solution": "iotss-0000-uat-aue",
    "iot_security_solution1": "iotss-0000-uat-01",
    "iot_security_solution2": "iotss-0000-uat-02",
    "iot_security_solution3": "iotss-0000-uat-03",
    "iotcentral_application": "iotapp-0000-uat",
    "iotcentral_application1": "iotapp-0000-uat-01",
    "iotcentral_application2": "iotapp-0000-uat-02",
    "iotcentral_application3": "iotapp-0000-uat-03",
    "iothub": "iot-0000-uat",
    "iothub1": "iot-0000-uat-01",
    "iothub2": "iot-0000-uat-02",
    "iothub3": "iot-0000-uat-03",
    "iothub_certificate": "iotcert-0000-uat-aue",
    "iothub_certificate1": "iotcert-0000-uat-01",
    "iothub_certificate2": "iotcert-0000-uat-02",
    "iothub_certificate3": "iotcert-0000-uat-03",
    "iothub_consumer_group": "iotcg-0000-uat-aue",
    "iothub_consumer_group1": "iotcg-0000-uat-01",
    "iothub_consumer_group2": "iotcg-0000-uat-02",
    "iothub_consumer_group3": "iotcg-0000-uat-03",
    "iothub_dps": "dps-0000-uat-aue",
    "iothub_dps1": "dps-0000-uat-01",
    "iothub_dps2": "dps-0000-uat-02",
    "iothub_dps3": "dps-0000-uat-03",
    "iothub_dps_certificate": "dpscert-0000-uat-aue",
    "iothub_dps_certificate1": "dpscert-0000-uat-01",
    "iothub_dps_certificate2": "dpscert-0000-uat-02",
    "iothub_dps_certificate3": "dpscert-0000-uat-03",
    "iothub_dps_shared_access_policy": "dpssap-0000-uat-aue",
    "iothub_dps_shared_access_policy1": "dpssap-0000-uat-01",
    "iothub_dps_shared_access_policy2": "dpssap-0000-uat-02",
    "iothub_dps_shared_access_policy3": "dpssap-0000-uat-03",
    "iothub_shared_access_policy": "iotsap-0000-uat-aue",
    "iothub_shared_access_policy1": "iotsap-0000-uat-01",
    "iothub_shared_access_policy2": "iotsap-0000-uat-02",
    "iothub_shared_access_policy3": "iotsap-0000-uat-03",
    "ip_group": "ipgr-0000-uat-aue",
    "ip_group1": "ipgr-0000-uat-01",
    "ip_group2": "ipgr-0000-uat-02",
    "ip_group3": "ipgr-0000-uat-03",
    "key_vault": "kv-0000-uat",
    "key_vault1": "kv-0000-uat-01",
    "key_vault2": "kv-0000-uat-02",
    "key_vault3": "kv-0000-uat-03",
    "key_vault_certificate": "kvc-0000-uat-aue",
    "key_vault_certificate1": "kvc-0000-uat-01",
    "key_vault_certificate2": "kvc-0000-uat-02",
    "key_vault_certificate3": "kvc-0000-uat-03",
    "key_vault_key": "kvk-0000-uat-aue",
    "key_vault_key1": "kvk-0000-uat-01",
    "key_vault_key2": "kvk-0000-uat-02",
    "key_vault_key3": "kvk-0000-uat-03",
    "key_vault_secret": "kvs-0000-uat-aue",
    "key_vault_secret1": "kvs-0000-uat-01",
    "key_vault_secret2": "kvs-0000-uat-02",
    "key_vault_secret3": "kvs-0000-uat-03",
    "kubernetes_cluster": "aks-0000-uat-aue",
    "kubernetes_cluster1": "aks-0000-uat-01",
    "kubernetes_cluster2": "aks-0000-uat-02",
    "kubernetes_cluster3": "aks-0000-uat-03",
    "kubernetes_fleet_manager": "fleet-0000-uat-aue",
    "kubernetes_fleet_manager1": "fleet-0000-uat-01",
    "kubernetes_fleet_manager2": "fleet-0000-uat-02",
    "kubernetes_fleet_manager3": "fleet-0000-uat-03",
    "kusto_cluster": "kc0000uat",
    "kusto_cluster1": "kc0000uat01",
    "kusto_cluster2": "kc0000uat02",
    "kusto_cluster3": "kc0000uat03",
    "kusto_database": "kdb-0000-uat-aue",
    "kusto_database1": "kdb-0000-uat-01",
    "kusto_database2": "kdb-0000-uat-02",
    "kusto_database3": "kdb-0000-uat-03",
    "kusto_eventhub_data_connection": "kehc-0000-uat-aue",
    "kusto_eventhub_data_connection1": "kehc-0000-uat-01",
    "kusto_eventhub_data_connection2": "kehc-0000-uat-02",
    "kusto_eventhub_data_connection3": "kehc-0000-uat-03",
    "lb": "lb-0000-uat-aue",
    "lb1": "lb-0000-uat-01",
    "lb2": "lb-0000-uat-02",
    "lb3": "lb-0000-uat-03",
    "lb_backend_address_pool": "adt-0000-uat-aue",
    "lb_backend_address_pool1": "adt-0000-uat-01",
    "lb_backend_address_pool2": "adt-0000-uat-02",
    "lb_backend_address_pool3": "adt-0000-uat-03",
    "lb_backend_pool": "adt-0000-uat-aue",
    "lb_backend_pool1": "adt-0000-uat-01",
    "lb_backend_pool2": "adt-0000-uat-02",
    "lb_backend_pool3": "adt-0000-uat-03",
    "lb_nat_pool": "adt-0000-uat-aue",
    "lb_nat_pool1": "adt-0000-uat-01",
    "lb_nat_pool2": "adt-0000-uat-02",
    "lb_nat_pool3": "adt-0000-uat-03",
    "lb_nat_rule": "lbnatrl-0000-uat-aue",
    "lb_nat_rule1": "lbnatrl-0000-uat-01",
    "lb_nat_rule2": "lbnatrl-0000-uat-02",
    "lb_nat_rule3": "lbnatrl-0000-uat-03",
    "lb_outbound_rule": "adt-0000-uat-aue",
    "lb_outbound_rule1": "adt-0000-uat-01",
    "lb_outbound_rule2": "adt-0000-uat-02",
    "lb_outbound_rule3": "adt-0000-uat-03",
    "lb_probe": "adt-0000-uat-aue",
    "lb_probe1": "adt-0000-uat-01",
    "lb_probe2": "adt-0000-uat-02",
    "lb_probe3": "adt-0000-uat-03",
    "lb_rule": "adt-0000-uat-aue",
    "lb_rule1": "adt-0000-uat-01",
    "lb_rule2": "adt-0000-uat-02",
    "lb_rule3": "adt-0000-uat-03",
    "linux_virtual_machine": "vm-0000-uat-aue",
    "linux_virtual_machine1": "vm-0000-uat-01",
    "linux_virtual_machine2": "vm-0000-uat-02",
    "linux_virtual_machine3": "vm-0000-uat-03",
    "linux_virtual_machine_scale_set": "vmss-0000-uat-aue",
    "linux_virtual_machine_scale_set1": "vmss-0000-uat-01",
    "linux_virtual_machine_scale_set2": "vmss-0000-uat-02",
    "linux_virtual_machine_scale_set3": "vmss-0000-uat-03",
    "linux_web_app": "lwapp-0000-uat",
    "linux_web_app1": "lwapp-0000-uat-01",
    "linux_web_app2": "lwapp-0000-uat-02",
    "linux_web_app3": "lwapp-0000-uat-03",
    "load_test": "load-0000-uat",
    "load_test1": "load-0000-uat-01",
    "load_test2": "load-0000-uat-02",
    "load_test3": "load-0000-uat-03",
    "local_network_gateway": "lgw-0000-uat-aue",
    "local_network_gateway1": "lgw-0000-uat-01",
    "local_network_gateway2": "lgw-0000-uat-02",
    "local_network_gateway3": "lgw-0000-uat-03",
    "log_analytics_cluster": "logc-0000-uat-aue",
    "log_analytics_cluster1": "logc-0000-uat-01",
    "log_analytics_cluster2": "logc-0000-uat-02",
    "log_analytics_cluster3": "logc-0000-uat-03",
    "log_analytics_storage_insights": "lasi-0000-uat-aue",
    "log_analytics_storage_insights1": "lasi-0000-uat-01",
    "log_analytics_storage_insights2": "lasi-0000-uat-02",
    "log_analytics_storage_insights3": "lasi-0000-uat-03",
    "log_analytics_workspace": "log-0000-uat-aue",
    "log_analytics_workspace1": "log-0000-uat-01",
    "log_analytics_workspace2": "log-0000-uat-02",
    "log_analytics_workspace3": "log-0000-uat-03",
    "logic_app_action_custom": "lappac-0000-uat-aue",
    "logic_app_action_custom1": "lappac-0000-uat-01",
    "logic_app_action_custom2": "lappac-0000-uat-02",
    "logic_app_action_custom3": "lappac-0000-uat-03",
    "logic_app_action_http": "lappah-0000-uat-aue",
    "logic_app_action_http1": "lappah-0000-uat-01",
    "logic_app_action_http2": "lappah-0000-uat-02",
    "logic_app_action_http3": "lappah-0000-uat-03",
    "logic_app_integration_account": "lappia-0000-uat-aue",
    "logic_app_integration_account1": "lappia-0000-uat-01",
    "logic_app_integration_account2": "lappia-0000-uat-02",
    "logic_app_integration_account3": "lappia-0000-uat-03",
    "logic_app_trigger_custom": "lapptc-0000-uat-aue",
    "logic_app_trigger_custom1": "lapptc-0000-uat-01",
    "logic_app_trigger_custom2": "lapptc-0000-uat-02",
    "logic_app_trigger_custom3": "lapptc-0000-uat-03",
    "logic_app_trigger_http_request": "lappth-0000-uat-aue",
    "logic_app_trigger_http_request1": "lappth-0000-uat-01",
    "logic_app_trigger_http_request2": "lappth-0000-uat-02",
    "logic_app_trigger_http_request3": "lappth-0000-uat-03",
    "logic_app_trigger_recurrence": "lapptc-0000-uat-aue",
    "logic_app_trigger_recurrence1": "lapptc-0000-uat-01",
    "logic_app_trigger_recurrence2": "lapptc-0000-uat-02",
    "logic_app_trigger_recurrence3": "lapptc-0000-uat-03",
    "logic_app_workflow": "lapp-0000-uat-aue",
    "logic_app_workflow1": "lapp-0000-uat-01",
    "logic_app_workflow2": "lapp-0000-uat-02",
    "logic_app_workflow3": "lapp-0000-uat-03",
    "machine_learning_compute_instance": "amlci-0000-uat",
    "machine_learning_compute_instance1": "amlci-0000-01",
    "machine_learning_compute_instance2": "amlci-0000-02",
    "machine_learning_compute_instance3": "amlci-0000-03",
    "machine_learning_workspace": "mlw-0000-uat-aue",
    "machine_learning_workspace1": "mlw-0000-uat-01",
    "machine_learning_workspace2": "mlw-0000-uat-02",
    "machine_learning_workspace3": "mlw-0000-uat-03",
    "maintenance_configuration": "mcf-0000-uat-aue",
    "maintenance_configuration1": "mcf-0000-uat-01",
    "maintenance_configuration2": "mcf-0000-uat-02",
    "maintenance_configuration3": "mcf-0000-uat-03",
    "managed_disk": "dsk-0000-uat-aue",
    "managed_disk1": "dsk-0000-uat-01",
    "managed_disk2": "dsk-0000-uat-02",
    "managed_disk3": "dsk-0000-uat-03",
    "maps_account": "map-0000-uat-aue",
    "maps_account1": "map-0000-uat-01",
    "maps_account2": "map-0000-uat-02",
    "maps_account3": "map-0000-uat-03",
    "mariadb_database": "mariadb-0000-uat-aue",
    "mariadb_database1": "mariadb-0000-uat-01",
    "mariadb_database2": "mariadb-0000-uat-02",
    "mariadb_database3": "mariadb-0000-uat-03",
    "mariadb_firewall_rule": "mariafw-0000-uat-aue",
    "mariadb_firewall_rule1": "mariafw-0000-uat-01",
    "mariadb_firewall_rule2": "mariafw-0000-uat-02",
    "mariadb_firewall_rule3": "mariafw-0000-uat-03",
    "mariadb_server": "maria-0000-uat",
    "mariadb_server1": "maria-0000-uat-01",
    "mariadb_server2": "maria-0000-uat-02",
    "mariadb_server3": "maria-0000-uat-03",
    "mariadb_virtual_network_rule": "mariavn-0000-uat-aue",
    "mariadb_virtual_network_rule1": "mariavn-0000-uat-01",
    "mariadb_virtual_network_rule2": "mariavn-0000-uat-02",
    "mariadb_virtual_network_rule3": "mariavn-0000-uat-03",
    "monitor_action_group": "amag-0000-uat-aue",
    "monitor_action_group1": "amag-0000-uat-01",
    "monitor_action_group2": "amag-0000-uat-02",
    "monitor_action_group3": "amag-0000-uat-03",
    "monitor_activity_log_alert": "adfmysql-0000-uat-aue",
    "monitor_activity_log_alert1": "adfmysql-0000-uat-01",
    "monitor_activity_log_alert2": "adfmysql-0000-uat-02",
    "monitor_activity_log_alert3": "adfmysql-0000-uat-03",
    "monitor_autoscale_setting": "amas-0000-uat-aue",
    "monitor_autoscale_setting1": "amas-0000-uat-01",
    "monitor_autoscale_setting2": "amas-0000-uat-02",
    "monitor_autoscale_setting3": "amas-0000-uat-03",
    "monitor_data_collection_endpoint": "dce-0000-uat-aue",
    "monitor_data_collection_endpoint1": "dce-0000-uat-01",
    "monitor_data_collection_endpoint2": "dce-0000-uat-02",
    "monitor_data_collection_endpoint3": "dce-0000-uat-03",
    "monitor_diagnostic_setting": "amds-0000-uat-aue",
    "monitor_diagnostic_setting1": "amds-0000-uat-01",
    "monitor_diagnostic_setting2": "amds-0000-uat-02",
    "monitor_diagnostic_setting3": "amds-0000-uat-03",
    "monitor_metric_alert": "ma-0000-uat-aue",
    "monitor_metric_alert1": "ma-0000-uat-01",
    "monitor_metric_alert2": "ma-0000-uat-02",
    "monitor_metric_alert3": "ma-0000-uat-03",
    "monitor_private_link_scope": "ampls-0000-uat-aue",
    "monitor_private_link_scope1": "ampls-0000-uat-01",
    "monitor_private_link_scope2": "ampls-0000-uat-02",
    "monitor_private_link_scope3": "ampls-0000-uat-03",
    "monitor_scheduled_query_rules_alert": "schqra-0000-uat-aue",
    "monitor_scheduled_query_rules_alert1": "schqra-0000-uat-01",
    "monitor_scheduled_query_rules_alert2": "schqra-0000-uat-02",
    "monitor_scheduled_query_rules_alert3": "schqra-0000-uat-03",
    "mssql_database": "sqldb-0000-uat-aue",
    "mssql_database1": "sqldb-0000-uat-01",
    "mssql_database2": "sqldb-0000-uat-02",
    "mssql_database3": "sqldb-0000-uat-03",
    "mssql_elasticpool": "sqlep-0000-uat-aue",
    "mssql_elasticpool1": "sqlep-0000-uat-01",
    "mssql_elasticpool2": "sqlep-0000-uat-02",
    "mssql_elasticpool3": "sqlep-0000-uat-03",
    "mssql_mi": "sqlmi-0000-uat",
    "mssql_mi1": "sqlmi-0000-uat-01",
    "mssql_mi2": "sqlmi-0000-uat-02",
    "mssql_mi3": "sqlmi-0000-uat-03",
    "mssql_server": "sql-0000-uat",
    "mssql_server1": "sql-0000-uat-01",
    "mssql_server2": "sql-0000-uat-02",
    "mssql_server3": "sql-0000-uat-03",
    "mysql_database": "mysqldb-0000-uat-aue",
    "mysql_database1": "mysqldb-0000-uat-01",
    "mysql_database2": "mysqldb-0000-uat-02",
    "mysql_database3": "mysqldb-0000-uat-03",
    "mysql_firewall_rule": "mysqlfw-0000-uat-aue",
    "mysql_firewall_rule1": "mysqlfw-0000-uat-01",
    "mysql_firewall_rule2": "mysqlfw-0000-uat-02",
    "mysql_firewall_rule3": "mysqlfw-0000-uat-03",
    "mysql_flexible_server": "mysqlf-0000-uat",
    "mysql_flexible_server1": "mysqlf-0000-uat-01",
    "mysql_flexible_server2": "mysqlf-0000-uat-02",
    "mysql_flexible_server3": "mysqlf-0000-uat-03",
    "mysql_flexible_server_database": "mysqlfdb-0000-uat-aue",
    "mysql_flexible_server_database1": "mysqlfdb-0000-uat-01",
    "mysql_flexible_server_database2": "mysqlfdb-0000-uat-02",
    "mysql_flexible_server_database3": "mysqlfdb-0000-uat-03",
    "mysql_flexible_server_firewall_rule": "mysqlffw-0000-uat-aue",
    "mysql_flexible_server_firewall_rule1": "mysqlffw-0000-uat-01",
    "mysql_flexible_server_firewall_rule2": "mysqlffw-0000-uat-02",
    "mysql_flexible_server_firewall_rule3": "mysqlffw-0000-uat-03",
    "mysql_server": "mysql-0000-uat",
    "mysql_server1": "mysql-0000-uat-01",
    "mysql_server2": "mysql-0000-uat-02",
    "mysql_server3": "mysql-0000-uat-03",
    "mysql_virtual_network_rule": "mysqlvn-0000-uat-aue",
    "mysql_virtual_network_rule1": "mysqlvn-0000-uat-01",
    "mysql_virtual_network_rule2": "mysqlvn-0000-uat-02",
    "mysql_virtual_network_rule3": "mysqlvn-0000-uat-03",
    "netapp_account": "ana-0000-uat-aue",
    "netapp_account1": "ana-0000-uat-01",
    "netapp_account2": "ana-0000-uat-02",
    "netapp_account3": "ana-0000-uat-03",
    "netapp_pool": "anp-0000-uat-aue",
    "netapp_pool1": "anp-0000-uat-01",
    "netapp_pool2": "anp-0000-uat-02",
    "netapp_pool3": "anp-0000-uat-03",
    "netapp_snapshot": "ans-0000-uat-aue",
    "netapp_snapshot1": "ans-0000-uat-01",
    "netapp_snapshot2": "ans-0000-uat-02",
    "netapp_snapshot3": "ans-0000-uat-03",
    "netapp_volume": "anv-0000-uat-aue",
    "netapp_volume1": "anv-0000-uat-01",
    "netapp_volume2": "anv-0000-uat-02",
    "netapp_volume3": "anv-0000-uat-03",
    "network_interface": "nic-0000-uat-aue",
    "network_interface1": "nic-0000-uat-01",
    "network_interface2": "nic-0000-uat-02",
    "network_interface3": "nic-0000-uat-03",
    "network_security_group": "nsg-0000-uat-aue",
    "network_security_group1": "nsg-0000-uat-01",
    "network_security_group2": "nsg-0000-uat-02",
    "network_security_group3": "nsg-0000-uat-03",
    "network_security_group_rule": "nsgr-0000-uat-aue",
    "network_security_group_rule1": "nsgr-0000-uat-01",
    "network_security_group_rule2": "nsgr-0000-uat-02",
    "network_security_group_rule3": "nsgr-0000-uat-03",
    "network_security_rule": "nsgr-0000-uat-aue",
    "network_security_rule1": "nsgr-0000-uat-01",
    "network_security_rule2": "nsgr-0000-uat-02",
    "network_security_rule3": "nsgr-0000-uat-03",
    "network_watcher": "nw-0000-uat-aue",
    "network_watcher1": "nw-0000-uat-01",
    "network_watcher2": "nw-0000-uat-02",
    "network_watcher3": "nw-0000-uat-03",
    "nginx_deployment": "nginx-0000-uat-aue",
    "nginx_deployment1": "nginx-0000-uat-01",
    "nginx_deployment2": "nginx-0000-uat-02",
    "nginx_deployment3": "nginx-0000-uat-03",
    "notification_hub": "nh-0000-uat-aue",
    "notification_hub1": "nh-0000-uat-01",
    "notification_hub2": "nh-0000-uat-02",
    "notification_hub3": "nh-0000-uat-03",
    "notification_hub_authorization_rule": "dnsrec-0000-uat-aue",
    "notification_hub_authorization_rule1": "dnsrec-0000-uat-01",
    "notification_hub_authorization_rule2": "dnsrec-0000-uat-02",
    "notification_hub_authorization_rule3": "dnsrec-0000-uat-03",
    "notification_hub_namespace": "dnsrec-0000-uat",
    "notification_hub_namespace1": "dnsrec-0000-uat-01",
    "notification_hub_namespace2": "dnsrec-0000-uat-02",
    "notification_hub_namespace3": "dnsrec-0000-uat-03",
    "point_to_site_vpn_gateway": "vpngw-0000-uat-aue",
    "point_to_site_vpn_gateway1": "vpngw-0000-uat-01",
    "point_to_site_vpn_gateway2": "vpngw-0000-uat-02",
    "point_to_site_vpn_gateway3": "vpngw-0000-uat-03",
    "portal_dashboard": "dsb-0000-uat-aue",
    "portal_dashboard1": "dsb-0000-uat-01",
    "portal_dashboard2": "dsb-0000-uat-02",
    "portal_dashboard3": "dsb-0000-uat-03",
    "postgresql_database": "psqldb-0000-uat-aue",
    "postgresql_database1": "psqldb-0000-uat-01",
    "postgresql_database2": "psqldb-0000-uat-02",
    "postgresql_database3": "psqldb-0000-uat-03",
    "postgresql_firewall_rule": "psqlfw-0000-uat-aue",
    "postgresql_firewall_rule1": "psqlfw-0000-uat-01",
    "postgresql_firewall_rule2": "psqlfw-0000-uat-02",
    "postgresql_firewall_rule3": "psqlfw-0000-uat-03",
    "postgresql_flexible_server": "psqlf-0000-uat",
    "postgresql_flexible_server1": "psqlf-0000-uat-01",
    "postgresql_flexible_server2": "psqlf-0000-uat-02",
    "postgresql_flexible_server3": "psqlf-0000-uat-03",
    "postgresql_flexible_server_database": "psqlfdb-0000-uat-aue",
    "postgresql_flexible_server_database1": "psqlfdb-0000-uat-01",
    "postgresql_flexible_server_database2": "psqlfdb-0000-uat-02",
    "postgresql_flexible_server_database3": "psqlfdb-0000-uat-03",
    "postgresql_flexible_server_firewall_rule": "psqlffw-0000-uat-aue",
    "postgresql_flexible_server_firewall_rule1": "psqlffw-0000-uat-01",
    "postgresql_flexible_server_firewall_rule2": "psqlffw-0000-uat-02",
    "postgresql_flexible_server_firewall_rule3": "psqlffw-0000-uat-03",
    "postgresql_server": "psql-0000-uat",
    "postgresql_server1": "psql-0000-uat-01",
    "postgresql_server2": "psql-0000-uat-02",
    "postgresql_server3": "psql-0000-uat-03",
    "postgresql_virtual_network_rule": "psqlvn-0000-uat-aue",
    "postgresql_virtual_network_rule1": "psqlvn-0000-uat-01",
    "postgresql_virtual_network_rule2": "psqlvn-0000-uat-02",
    "postgresql_virtual_network_rule3": "psqlvn-0000-uat-03",
    "powerbi_embedded": "pbi0000uataue",
    "powerbi_embedded1": "pbi0000uat01",
    "powerbi_embedded2": "pbi0000uat02",
    "powerbi_embedded3": "pbi0000uat03",
    "private_dns_resolver": "dnspr-0000-uat-aue",
    "private_dns_resolver1": "dnspr-0000-uat-01",
    "private_dns_resolver2": "dnspr-0000-uat-02",
    "private_dns_resolver3": "dnspr-0000-uat-03",
    "private_dns_resolver_dns_forwarding_ruleset": "dnsfwrs-0000-uat-aue",
    "private_dns_resolver_dns_forwarding_ruleset1": "dnsfwrs-0000-uat-01",
    "private_dns_resolver_dns_forwarding_ruleset2": "dnsfwrs-0000-uat-02",
    "private_dns_resolver_dns_forwarding_ruleset3": "dnsfwrs-0000-uat-03",
    "private_dns_resolver_forwarding_rule": "dnsfwr-0000-uat-aue",
    "private_dns_resolver_forwarding_rule1": "dnsfwr-0000-uat-01",
    "private_dns_resolver_forwarding_rule2": "dnsfwr-0000-uat-02",
    "private_dns_resolver_forwarding_rule3": "dnsfwr-0000-uat-03",
    "private_dns_resolver_inbound_endpoint": "dnsprie-0000-uat-aue",
    "private_dns_resolver_inbound_endpoint1": "dnsprie-0000-uat-01",
    "private_dns_resolver_inbound_endpoint2": "dnsprie-0000-uat-02",
    "private_dns_resolver_inbound_endpoint3": "dnsprie-0000-uat-03",
    "private_dns_resolver_outbound_endpoint": "dnsproe-0000-uat-aue",
    "private_dns_resolver_outbound_endpoint1": "dnsproe-0000-uat-01",
    "private_dns_resolver_outbound_endpoint2": "dnsproe-0000-uat-02",
    "private_dns_resolver_outbound_endpoint3": "dnsproe-0000-uat-03",
    "private_dns_resolver_virtual_network_link": "dnsfwrsvnetl-0000-uat-aue",
    "private_dns_resolver_virtual_network_link1": "dnsfwrsvnetl-0000-uat-01",
    "private_dns_resolver_virtual_network_link2": "dnsfwrsvnetl-0000-uat-02",
    "private_dns_resolver_virtual_network_link3": "dnsfwrsvnetl-0000-uat-03",
    "private_dns_zone": "pdns-0000-uat-aue",
    "private_dns_zone1": "pdns-0000-uat-01",
    "private_dns_zone2": "pdns-0000-uat-02",
    "private_dns_zone3": "pdns-0000-uat-03",
    "private_dns_zone_virtual_network_link": "pnetlk-0000-uat-aue",
    "private_dns_zone_virtual_network_link1": "pnetlk-0000-uat-01",
    "private_dns_zone_virtual_network_link2": "pnetlk-0000-uat-02",
    "private_dns_zone_virtual_network_link3": "pnetlk-0000-uat-03",
    "private_endpoint": "pe-0000-uat-aue",
    "private_endpoint1": "pe-0000-uat-01",
    "private_endpoint2": "pe-0000-uat-02",
    "private_endpoint3": "pe-0000-uat-03",
    "public_ip": "pip-0000-uat-aue",
    "public_ip1": "pip-0000-uat-01",
    "public_ip2": "pip-0000-uat-02",
    "public_ip3": "pip-0000-uat-03",
    "public_ip_prefix": "pippf-0000-uat-aue",
    "public_ip_prefix1": "pippf-0000-uat-01",
    "public_ip_prefix2": "pippf-0000-uat-02",
    "public_ip_prefix3": "pippf-0000-uat-03",
    "purview_account": "purv-0000-uat-aue",
    "purview_account1": "purv-0000-uat-01",
    "purview_account2": "purv-0000-uat-02",
    "purview_account3": "purv-0000-uat-03",
    "recovery_services_vault": "rsv-0000-uat-aue",
    "recovery_services_vault1": "rsv-0000-uat-01",
    "recovery_services_vault2": "rsv-0000-uat-02",
    "recovery_services_vault3": "rsv-0000-uat-03",
    "recovery_services_vault_backup_police": "rsvbp-0000-uat-aue",
    "recovery_services_vault_backup_police1": "rsvbp-0000-uat-01",
    "recovery_services_vault_backup_police2": "rsvbp-0000-uat-02",
    "recovery_services_vault_backup_police3": "rsvbp-0000-uat-03",
    "redhat_openshift_cluster": "aroc0000uataue",
    "redhat_openshift_cluster1": "aroc0000uat01",
    "redhat_openshift_cluster2": "aroc0000uat02",
    "redhat_openshift_cluster3": "aroc0000uat03",
    "redhat_openshift_domain": "arod0000uataue",
    "redhat_openshift_domain1": "arod0000uat01",
    "redhat_openshift_domain2": "arod0000uat02",
    "redhat_openshift_domain3": "arod0000uat03",
    "redis_cache": "redis-0000-uat",
    "redis_cache1": "redis-0000-uat-01",
    "redis_cache2": "redis-0000-uat-02",
    "redis_cache3": "redis-0000-uat-03",
    "redis_firewall_rule": "redisfw0000uataue",
    "redis_firewall_rule1": "redisfw0000uat01",
    "redis_firewall_rule2": "redisfw0000uat02",
    "redis_firewall_rule3": "redisfw0000uat03",
    "relay_hybrid_connection": "rlhc-0000-uat-aue",
    "relay_hybrid_connection1": "rlhc-0000-uat-01",
    "relay_hybrid_connection2": "rlhc-0000-uat-02",
    "relay_hybrid_connection3": "rlhc-0000-uat-03",
    "relay_namespace": "rln-0000-uat",
    "relay_namespace1": "rln-0000-uat-01",
    "relay_namespace2": "rln-0000-uat-02",
    "relay_namespace3": "rln-0000-uat-03",
    "resource_group": "rg-0000-uat-aue",
    "resource_group1": "rg-0000-uat-01",
    "resource_group2": "rg-0000-uat-02",
    "resource_group3": "rg-0000-uat-03",
    "resource_group_policy_assignment": "argpa-0000-uat-aue",
    "resource_group_policy_assignment1": "argpa-0000-uat-01",
    "resource_group_policy_assignment2": "argpa-0000-uat-02",
    "resource_group_policy_assignment3": "argpa-0000-uat-03",
    "role_assignment": "ra-0000-uat-aue",
    "role_assignment1": "ra-0000-uat-01",
    "role_assignment2": "ra-0000-uat-02",
    "role_assignment3": "ra-0000-uat-03",
    "role_definition": "rd-0000-uat-aue",
    "role_definition1": "rd-0000-uat-01",
    "role_definition2": "rd-0000-uat-02",
    "role_definition3": "rd-0000-uat-03",
    "route": "rt-0000-uat-aue",
    "route1": "rt-0000-uat-01",
    "route2": "rt-0000-uat-02",
    "route3": "rt-0000-uat-03",
    "route_server": "rts-0000-uat-aue",
    "route_server1": "rts-0000-uat-01",
    "route_server2": "rts-0000-uat-02",
    "route_server3": "rts-0000-uat-03",
    "route_table": "route-0000-uat-aue",
    "route_table1": "route-0000-uat-01",
    "route_table2": "route-0000-uat-02",
    "route_table3": "route-0000-uat-03",
    "search_service": "srch-0000-uat",
    "search_service1": "srch-0000-uat-01",
    "search_service2": "srch-0000-uat-02",
    "search_service3": "srch-0000-uat-03",
    "service_fabric_cluster": "sf-0000-uat-aue",
    "service_fabric_cluster1": "sf-0000-uat-01",
    "service_fabric_cluster2": "sf-0000-uat-02",
    "service_fabric_cluster3": "sf-0000-uat-03",
    "servicebus_namespace": "sb-0000-uat",
    "servicebus_namespace1": "sb-0000-uat-01",
    "servicebus_namespace2": "sb-0000-uat-02",
    "servicebus_namespace3": "sb-0000-uat-03",
    "servicebus_namespace_authorization_rule": "sbar-0000-uat-aue",
    "servicebus_namespace_authorization_rule1": "sbar-0000-uat-01",
    "servicebus_namespace_authorization_rule2": "sbar-0000-uat-02",
    "servicebus_namespace_authorization_rule3": "sbar-0000-uat-03",
    "servicebus_queue": "sbq-0000-uat-aue",
    "servicebus_queue1": "sbq-0000-uat-01",
    "servicebus_queue2": "sbq-0000-uat-02",
    "servicebus_queue3": "sbq-0000-uat-03",
    "servicebus_queue_authorization_rule": "sbqar-0000-uat-aue",
    "servicebus_queue_authorization_rule1": "sbqar-0000-uat-01",
    "servicebus_queue_authorization_rule2": "sbqar-0000-uat-02",
    "servicebus_queue_authorization_rule3": "sbqar-0000-uat-03",
    "servicebus_subscription": "sbs-0000-uat-aue",
    "servicebus_subscription1": "sbs-0000-uat-01",
    "servicebus_subscription2": "sbs-0000-uat-02",
    "servicebus_subscription3": "sbs-0000-uat-03",
    "servicebus_subscription_rule": "sbsr-0000-uat-aue",
    "servicebus_subscription_rule1": "sbsr-0000-uat-01",
    "servicebus_subscription_rule2": "sbsr-0000-uat-02",
    "servicebus_subscription_rule3": "sbsr-0000-uat-03",
    "servicebus_topic": "sbt-0000-uat-aue",
    "servicebus_topic1": "sbt-0000-uat-01",
    "servicebus_topic2": "sbt-0000-uat-02",
    "servicebus_topic3": "sbt-0000-uat-03",
    "servicebus_topic_authorization_rule": "sbtar-0000-uat-aue",
    "servicebus_topic_authorization_rule1": "sbtar-0000-uat-01",
    "servicebus_topic_authorization_rule2": "sbtar-0000-uat-02",
    "servicebus_topic_authorization_rule3": "sbtar-0000-uat-03",
    "shared_image": "si-0000-uat-aue",
    "shared_image1": "si-0000-uat-01",
    "shared_image2": "si-0000-uat-02",
    "shared_image3": "si-0000-uat-03",
    "shared_image_gallery": "sig0000uataue",
    "shared_image_gallery1": "sig0000uat01",
    "shared_image_gallery2": "sig0000uat02",
    "shared_image_gallery3": "sig0000uat03",
    "signalr_service": "sgnlr-0000-uat",
    "signalr_service1": "sgnlr-0000-uat-01",
    "signalr_service2": "sgnlr-0000-uat-02",
    "signalr_service3": "sgnlr-0000-uat-03",
    "snapshots": "snap-0000-uat-aue",
    "snapshots1": "snap-0000-uat-01",
    "snapshots2": "snap-0000-uat-02",
    "snapshots3": "snap-0000-uat-03",
    "sql_elasticpool": "sqlep-0000-uat-aue",
    "sql_elasticpool1": "sqlep-0000-uat-01",
    "sql_elasticpool2": "sqlep-0000-uat-02",
    "sql_elasticpool3": "sqlep-0000-uat-03",
    "sql_failover_group": "sqlfg-0000-uat",
    "sql_failover_group1": "sqlfg-0000-uat-01",
    "sql_failover_group2": "sqlfg-0000-uat-02",
    "sql_failover_group3": "sqlfg-0000-uat-03",
    "sql_firewall_rule": "sqlfw-0000-uat-aue",
    "sql_firewall_rule1": "sqlfw-0000-uat-01",
    "sql_firewall_rule2": "sqlfw-0000-uat-02",
    "sql_firewall_rule3": "sqlfw-0000-uat-03",
    "sql_server": "sql-0000-uat",
    "sql_server1": "sql-0000-uat-01",
    "sql_server2": "sql-0000-uat-02",
    "sql_server3": "sql-0000-uat-03",
    "static_site": "stapp-0000-uat-aue",
    "static_site1": "stapp-0000-uat-01",
    "static_site2": "stapp-0000-uat-02",
    "static_site3": "stapp-0000-uat-03",
    "storage_account": "st0000uat",
    "storage_account1": "st0000uat01",
    "storage_account2": "st0000uat02",
    "storage_account3": "st0000uat03",
    "storage_blob": "blob-0000-uat-aue",
    "storage_blob1": "blob-0000-uat-01",
    "storage_blob2": "blob-0000-uat-02",
    "storage_blob3": "blob-0000-uat-03",
    "storage_container": "stct-0000-uat-aue",
    "storage_container1": "stct-0000-uat-01",
    "storage_container2": "stct-0000-uat-02",
    "storage_container3": "stct-0000-uat-03",
    "storage_data_lake_gen2_filesystem": "stdl-0000-uat-aue",
    "storage_data_lake_gen2_filesystem1": "stdl-0000-uat-01",
    "storage_data_lake_gen2_filesystem2": "stdl-0000-uat-02",
    "storage_data_lake_gen2_filesystem3": "stdl-0000-uat-03",
    "storage_queue": "stq-0000-uat-aue",
    "storage_queue1": "stq-0000-uat-01",
    "storage_queue2": "stq-0000-uat-02",
    "storage_queue3": "stq-0000-uat-03",
    "storage_share": "sts-0000-uat-aue",
    "storage_share1": "sts-0000-uat-01",
    "storage_share2": "sts-0000-uat-02",
    "storage_share3": "sts-0000-uat-03",
    "storage_share_directory": "sts-0000-uat-aue",
    "storage_share_directory1": "sts-0000-uat-01",
    "storage_share_directory2": "sts-0000-uat-02",
    "storage_share_directory3": "sts-0000-uat-03",
    "storage_sync": "stsy-0000-uat-aue",
    "storage_sync1": "stsy-0000-uat-01",
    "storage_sync2": "stsy-0000-uat-02",
    "storage_sync3": "stsy-0000-uat-03",
    "storage_sync_group": "stsg-0000-uat-aue",
    "storage_sync_group1": "stsg-0000-uat-01",
    "storage_sync_group2": "stsg-0000-uat-02",
    "storage_sync_group3": "stsg-0000-uat-03",
    "storage_table": "stt-0000-uat-aue",
    "storage_table1": "stt-0000-uat-01",
    "storage_table2": "stt-0000-uat-02",
    "storage_table3": "stt-0000-uat-03",
    "stream_analytics_function_javascript_udf": "asafunc-0000-uat-aue",
    "stream_analytics_function_javascript_udf1": "asafunc-0000-uat-01",
    "stream_analytics_function_javascript_udf2": "asafunc-0000-uat-02",
    "stream_analytics_function_javascript_udf3": "asafunc-0000-uat-03",
    "stream_analytics_job": "asa-0000-uat-aue",
    "stream_analytics_job1": "asa-0000-uat-01",
    "stream_analytics_job2": "asa-0000-uat-02",
    "stream_analytics_job3": "asa-0000-uat-03",
    "stream_analytics_output_blob": "asaoblob-0000-uat-aue",
    "stream_analytics_output_blob1": "asaoblob-0000-uat-01",
    "stream_analytics_output_blob2": "asaoblob-0000-uat-02",
    "stream_analytics_output_blob3": "asaoblob-0000-uat-03",
    "stream_analytics_output_eventhub": "asaoeh-0000-uat-aue",
    "stream_analytics_output_eventhub1": "asaoeh-0000-uat-01",
    "stream_analytics_output_eventhub2": "asaoeh-0000-uat-02",
    "stream_analytics_output_eventhub3": "asaoeh-0000-uat-03",
    "stream_analytics_output_mssql": "asaomssql-0000-uat-aue",
    "stream_analytics_output_mssql1": "asaomssql-0000-uat-01",
    "stream_analytics_output_mssql2": "asaomssql-0000-uat-02",
    "stream_analytics_output_mssql3": "asaomssql-0000-uat-03",
    "stream_analytics_output_servicebus_queue": "asaosbq-0000-uat-aue",
    "stream_analytics_output_servicebus_queue1": "asaosbq-0000-uat-01",
    "stream_analytics_output_servicebus_queue2": "asaosbq-0000-uat-02",
    "stream_analytics_output_servicebus_queue3": "asaosbq-0000-uat-03",
    "stream_analytics_output_servicebus_topic": "asaosbt-0000-uat-aue",
    "stream_analytics_output_servicebus_topic1": "asaosbt-0000-uat-01",
    "stream_analytics_output_servicebus_topic2": "asaosbt-0000-uat-02",
    "stream_analytics_output_servicebus_topic3": "asaosbt-0000-uat-03",
    "stream_analytics_reference_input_blob": "asarblob-0000-uat-aue",
    "stream_analytics_reference_input_blob1": "asarblob-0000-uat-01",
    "stream_analytics_reference_input_blob2": "asarblob-0000-uat-02",
    "stream_analytics_reference_input_blob3": "asarblob-0000-uat-03",
    "stream_analytics_stream_input_blob": "asaiblob-0000-uat-aue",
    "stream_analytics_stream_input_blob1": "asaiblob-0000-uat-01",
    "stream_analytics_stream_input_blob2": "asaiblob-0000-uat-02",
    "stream_analytics_stream_input_blob3": "asaiblob-0000-uat-03",
    "stream_analytics_stream_input_eventhub": "asaieh-0000-uat-aue",
    "stream_analytics_stream_input_eventhub1": "asaieh-0000-uat-01",
    "stream_analytics_stream_input_eventhub2": "asaieh-0000-uat-02",
    "stream_analytics_stream_input_eventhub3": "asaieh-0000-uat-03",
    "stream_analytics_stream_input_iothub": "asaiiot-0000-uat-aue",
    "stream_analytics_stream_input_iothub1": "asaiiot-0000-uat-01",
    "stream_analytics_stream_input_iothub2": "asaiiot-0000-uat-02",
    "stream_analytics_stream_input_iothub3": "asaiiot-0000-uat-03",
    "subnet": "snet-0000-uat-aue",
    "subnet1": "snet-0000-uat-01",
    "subnet2": "snet-0000-uat-02",
    "subnet3": "snet-0000-uat-03",
    "subscription_policy_assignment": "aspa-0000-uat-aue",
    "subscription_policy_assignment1": "aspa-0000-uat-01",
    "subscription_policy_assignment2": "aspa-0000-uat-02",
    "subscription_policy_assignment3": "aspa-0000-uat-03",
    "synapse_firewall_rule": "syfw-0000-uat-aue",
    "synapse_firewall_rule1": "syfw-0000-uat-01",
    "synapse_firewall_rule2": "syfw-0000-uat-02",
    "synapse_firewall_rule3": "syfw-0000-uat-03",
    "synapse_integration_runtime_azure": "synira-0000-uat-aue",
    "synapse_integration_runtime_azure1": "synira-0000-uat-01",
    "synapse_integration_runtime_azure2": "synira-0000-uat-02",
    "synapse_integration_runtime_azure3": "synira-0000-uat-03",
    "synapse_integration_runtime_self_hosted": "synirsh-0000-uat-aue",
    "synapse_integration_runtime_self_hosted1": "synirsh-0000-uat-01",
    "synapse_integration_runtime_self_hosted2": "synirsh-0000-uat-02",
    "synapse_integration_runtime_self_hosted3": "synirsh-0000-uat-03",
    "synapse_linked_service": "synls0000uataue",
    "synapse_linked_service1": "synls0000uat01",
    "synapse_linked_service2": "synls0000uat02",
    "synapse_linked_service3": "synls0000uat03",
    "synapse_managed_private_endpoint": "synmpe-0000-uat-aue",
    "synapse_managed_private_endpoint1": "synmpe-0000-uat-01",
    "synapse_managed_private_endpoint2": "synmpe-0000-uat-02",
    "synapse_managed_private_endpoint3": "synmpe-0000-uat-03",
    "synapse_private_link_hub": "synplh0000uataue",
    "synapse_private_link_hub1": "synplh0000uat01",
    "synapse_private_link_hub2": "synplh0000uat02",
    "synapse_private_link_hub3": "synplh0000uat03",
    "synapse_spark_pool": "sysp0000uataue",
    "synapse_spark_pool1": "sysp0000uat01",
    "synapse_spark_pool2": "sysp0000uat02",
    "synapse_spark_pool3": "sysp0000uat03",
    "synapse_sql_pool": "synsp0000uataue",
    "synapse_sql_pool ": "sysql0000uataue",
    "synapse_sql_pool 1": "sysql0000uat01",
    "synapse_sql_pool 2": "sysql0000uat02",
    "synapse_sql_pool 3": "sysql0000uat03",
    "synapse_sql_pool1": "synsp0000uat01",
    "synapse_sql_pool2": "synsp0000uat02",
    "synapse_sql_pool3": "synsp0000uat03",
    "synapse_sql_pool_vulnerability_assessment_baseline": "synspvab0000uataue",
    "synapse_sql_pool_vulnerability_assessment_baseline1": "synspvab0000uat01",
    "synapse_sql_pool_vulnerability_assessment_baseline2": "synspvab0000uat02",
    "synapse_sql_pool_vulnerability_assessment_baseline3": "synspvab0000uat03",
    "synapse_sql_pool_workload_classifier": "synspwc-0000-uat-aue",
    "synapse_sql_pool_workload_classifier1": "synspwc-0000-uat-01",
    "synapse_sql_pool_workload_classifier2": "synspwc-0000-uat-02",
    "synapse_sql_pool_workload_classifier3": "synspwc-0000-uat-03",
    "synapse_sql_pool_workload_group": "synspwg-0000-uat-aue",
    "synapse_sql_pool_workload_group1": "synspwg-0000-uat-01",
    "synapse_sql_pool_workload_group2": "synspwg-0000-uat-02",
    "synapse_sql_pool_workload_group3": "synspwg-0000-uat-03",
    "synapse_workspace": "syws0000uataue",
    "synapse_workspace1": "syws0000uat01",
    "synapse_workspace2": "syws0000uat02",
    "synapse_workspace3": "syws0000uat03",
    "template_deployment": "deploy-0000-uat-aue",
    "template_deployment1": "deploy-0000-uat-01",
    "template_deployment2": "deploy-0000-uat-02",
    "template_deployment3": "deploy-0000-uat-03",
    "traffic_manager_profile": "traf-0000-uat",
    "traffic_manager_profile1": "traf-0000-uat-01",
    "traffic_manager_profile2": "traf-0000-uat-02",
    "traffic_manager_profile3": "traf-0000-uat-03",
    "user_assigned_identity": "msi-0000-uat-aue",
    "user_assigned_identity1": "msi-0000-uat-01",
    "user_assigned_identity2": "msi-0000-uat-02",
    "user_assigned_identity3": "msi-0000-uat-03",
    "virtual_desktop_application_group": "dag-0000-uat-aue",
    "virtual_desktop_application_group1": "dag-0000-uat-01",
    "virtual_desktop_application_group2": "dag-0000-uat-02",
    "virtual_desktop_application_group3": "dag-0000-uat-03",
    "virtual_desktop_host_pool": "hpool-0000-uat-aue",
    "virtual_desktop_host_pool1": "hpool-0000-uat-01",
    "virtual_desktop_host_pool2": "hpool-0000-uat-02",
    "virtual_desktop_host_pool3": "hpool-0000-uat-03",
    "virtual_desktop_workspace": "wvdws-0000-uat-aue",
    "virtual_desktop_workspace1": "wvdws-0000-uat-01",
    "virtual_desktop_workspace2": "wvdws-0000-uat-02",
    "virtual_desktop_workspace3": "wvdws-0000-uat-03",
    "virtual_hub": "vhub-0000-uat-aue",
    "virtual_hub1": "vhub-0000-uat-01",
    "virtual_hub2": "vhub-0000-uat-02",
    "virtual_hub3": "vhub-0000-uat-03",
    "virtual_hub_connection": "vhcon-0000-uat-aue",
    "virtual_hub_connection1": "vhcon-0000-uat-01",
    "virtual_hub_connection2": "vhcon-0000-uat-02",
    "virtual_hub_connection3": "vhcon-0000-uat-03",
    "virtual_machine": "vm0000uataue",
    "virtual_machine1": "vm0000uat01",
    "virtual_machine2": "vm0000uat02",
    "virtual_machine3": "vm0000uat03",
    "virtual_machine_portal_name": "vm-0000-uat-aue",
    "virtual_machine_portal_name1": "vm-0000-uat-01",
    "virtual_machine_portal_name2": "vm-0000-uat-02",
    "virtual_machine_portal_name3": "vm-0000-uat-03",
    "virtual_machine_scale_set": "vmss0000uataue",
    "virtual_machine_scale_set1": "vmss0000uat01",
    "virtual_machine_scale_set2": "vmss0000uat02",
    "virtual_machine_scale_set3": "vmss0000uat03",
    "virtual_network": "vnet-0000-uat-aue",
    "virtual_network1": "vnet-0000-uat-01",
    "virtual_network2": "vnet-0000-uat-02",
    "virtual_network3": "vnet-0000-uat-03",
    "virtual_network_gateway": "vgw-0000-uat-aue",
    "virtual_network_gateway1": "vgw-0000-uat-01",
    "virtual_network_gateway2": "vgw-0000-uat-02",
    "virtual_network_gateway3": "vgw-0000-uat-03",
    "virtual_network_peering": "vpeer-0000-uat-aue",
    "virtual_network_peering1": "vpeer-0000-uat-01",
    "virtual_network_peering2": "vpeer-0000-uat-02",
    "virtual_network_peering3": "vpeer-0000-uat-03",
    "virtual_wan": "vwan-0000-uat-aue",
    "virtual_wan1": "vwan-0000-uat-01",
    "virtual_wan2": "vwan-0000-uat-02",
    "virtual_wan3": "vwan-0000-uat-03",
    "vm_windows_computer_name_prefix": "cn0000uat",
    "vm_windows_computer_name_prefix1": "cn000001",
    "vm_windows_computer_name_prefix2": "cn000002",
    "vm_windows_computer_name_prefix3": "cn000003",
    "vmware_cluster": "vwc-0000-uat-aue",
    "vmware_cluster1": "vwc-0000-uat-01",
    "vmware_cluster2": "vwc-0000-uat-02",
    "vmware_cluster3": "vwc-0000-uat-03",
    "vmware_express_route_authorization": "vwera-0000-uat-aue",
    "vmware_express_route_authorization1": "vwera-0000-uat-01",
    "vmware_express_route_authorization2": "vwera-0000-uat-02",
    "vmware_express_route_authorization3": "vwera-0000-uat-03",
    "vmware_private_cloud": "vwpc-0000-uat-aue",
    "vmware_private_cloud1": "vwpc-0000-uat-01",
    "vmware_private_cloud2": "vwpc-0000-uat-02",
    "vmware_private_cloud3": "vwpc-0000-uat-03",
    "vpn_gateway_connection": "vcn-0000-uat-aue",
    "vpn_gateway_connection1": "vcn-0000-uat-01",
    "vpn_gateway_connection2": "vcn-0000-uat-02",
    "vpn_gateway_connection3": "vcn-0000-uat-03",
    "vpn_site": "vst-0000-uat-aue",
    "vpn_site1": "vst-0000-uat-01",
    "vpn_site2": "vst-0000-uat-02",
    "vpn_site3": "vst-0000-uat-03",
    "web_application_firewall_policy": "wafw0000uat",
    "web_application_firewall_policy1": "wafw0000uat01",
    "web_application_firewall_policy2": "wafw0000uat02",
    "web_application_firewall_policy3": "wafw0000uat03",
    "web_pubsub": "ps-0000-uat-aue",
    "web_pubsub1": "ps-0000-uat-01",
    "web_pubsub2": "ps-0000-uat-02",
    "web_pubsub3": "ps-0000-uat-03",
    "web_pubsub_hub": "pshub0000uataue",
    "web_pubsub_hub1": "pshub0000uat01",
    "web_pubsub_hub2": "pshub0000uat02",
    "web_pubsub_hub3": "pshub0000uat03",
    "windows_virtual_machine": "vm0000uataue",
    "windows_virtual_machine1": "vm0000uat01",
    "windows_virtual_machine2": "vm0000uat02",
    "windows_virtual_machine3": "vm0000uat03",
    "windows_virtual_machine_scale_set": "vmss0000uataue",
    "windows_virtual_machine_scale_set1": "vmss0000uat01",
    "windows_virtual_machine_scale_set2": "vmss0000uat02",
    "windows_virtual_machine_scale_set3": "vmss0000uat03",
    "windows_web_app": "wwapp-0000-uat",
    "windows_web_app1": "wwapp-0000-uat-01",
    "windows_web_app2": "wwapp-0000-uat-02",
    "windows_web_app3": "wwapp-0000-uat-03"
}
```